@@ -17,7 +17,7 @@
 #define _K3B_AUDIO_JOB_TEMPDATA_H_
 
 #include "k3bmsf.h"
-#include <QtCore/QObject>
+#include <QObject>
 
 namespace K3b {
     class AudioTrack;
@@ -28,7 +28,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        AudioJobTempData( AudioDoc* doc, QObject* parent = 0 );
+        explicit AudioJobTempData( AudioDoc* doc, QObject* parent = 0 );
         ~AudioJobTempData();
 
         QString bufferFileName( int track );
