@@ -20,8 +20,8 @@
 
 #include "k3bpluginconfigwidget.h"
 
-#include <QtCore/QList>
-#include <QtWidgets/QDialog>
+#include <QList>
+#include <QDialog>
 
 
 class QTreeWidgetItem;
@@ -31,7 +31,7 @@ class K3bExternalEncoderEditDialog : public QDialog, public Ui::base_K3bExternal
     Q_OBJECT
 
 public:
-    K3bExternalEncoderEditDialog( QWidget* parent );
+    explicit K3bExternalEncoderEditDialog( QWidget* parent );
     ~K3bExternalEncoderEditDialog();
 
     K3bExternalEncoderCommand currentCommand() const;
