@@ -15,7 +15,7 @@
 #ifndef _K3B_LSOF_WRAPPER_DIALOG_H_
 #define _K3B_LSOF_WRAPPER_DIALOG_H_
 
-#include <QtWidgets/QDialog>
+#include <QDialog>
 
 class QLabel;
 
@@ -46,7 +46,7 @@ namespace K3b {
         void slotQuitOtherApps();
 
     private:
-        LsofWrapperDialog( QWidget* parent );
+        explicit LsofWrapperDialog( QWidget* parent );
 
         Device::Device* m_device;
         QLabel* m_label;
