@@ -18,7 +18,7 @@
 #ifndef K3B_STATUSBAR_MANAGER_H
 #define K3B_STATUSBAR_MANAGER_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 class QLabel;
 class QEvent;
@@ -34,7 +34,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        StatusBarManager( MainWindow* parent );
+        explicit StatusBarManager( MainWindow* parent );
         ~StatusBarManager();
 
     public Q_SLOTS:
