@@ -15,7 +15,7 @@
 #ifndef _K3B_TIMEOUT_WIDGET_H_
 #define _K3B_TIMEOUT_WIDGET_H_
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 class QPaintEvent;
 class QResizeEvent;
@@ -27,7 +27,7 @@ class TimeoutWidget : public QWidget
   Q_OBJECT
 
  public:
-  TimeoutWidget( QWidget* parent );
+  explicit TimeoutWidget( QWidget* parent );
   ~TimeoutWidget();
 
   QSize sizeHint() const;
