@@ -17,11 +17,11 @@
 #ifndef _K3B_WELCOME_WIDGET_H_
 #define _K3B_WELCOME_WIDGET_H_
 
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QtGui/QImage>
-#include <QtGui/QPixmap>
-#include <QtWidgets/QWidget>
+#include <QList>
+#include <QMap>
+#include <QImage>
+#include <QPixmap>
+#include <QWidget>
 
 class KConfigGroup;
 class QDragEnterEvent;
@@ -42,7 +42,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        WelcomeWidget( MainWindow* mainWindow, QWidget* parent = 0 );
+        explicit WelcomeWidget( MainWindow* mainWindow, QWidget* parent = 0 );
         ~WelcomeWidget();
 
         void loadConfig( const KConfigGroup& c );
