@@ -17,7 +17,7 @@
 #ifndef _K3B_NOTIFY_OPTIONTAB_H_
 #define _K3B_NOTIFY_OPTIONTAB_H_
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 class KNotifyConfigWidget;
 
@@ -27,7 +27,7 @@ class NotifyOptionTab : public QWidget
   Q_OBJECT
 
  public:
-  NotifyOptionTab( QWidget* parent = 0 );
+  explicit NotifyOptionTab( QWidget* parent = 0 );
   ~NotifyOptionTab();
 
   void readSettings();
