@@ -17,7 +17,7 @@
 #define K3BOPTIONDIALOG_H
 
 #include <KWidgetsAddons/KPageDialog>
-#include <QtCore/QHash>
+#include <QHash>
 
 class KPageWidgetItem;
 namespace K3b {
@@ -54,7 +54,7 @@ class OptionDialog : public KPageDialog
     Q_OBJECT
 
 public:
-    OptionDialog( QWidget* parent = 0 );
+    explicit OptionDialog( QWidget* parent = 0 );
     ~OptionDialog();
 
     enum ConfigPage {
