@@ -17,8 +17,8 @@
 #ifndef K3BDATAPROPERTIESDIALOG_H
 #define K3BDATAPROPERTIESDIALOG_H
 
-#include <QtCore/QList>
-#include <QtWidgets/QDialog>
+#include <QList>
+#include <QDialog>
 
 class KLineEdit;
 class KSqueezedTextLabel;
@@ -37,7 +37,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        DataPropertiesDialog( const QList<DataItem*>&, QWidget* parent = 0 );
+        explicit DataPropertiesDialog( const QList<DataItem*>&, QWidget* parent = 0 );
         ~DataPropertiesDialog();
 
     protected Q_SLOTS:
